@@ -9,8 +9,8 @@ from veho.entries import zipper
 from veho.vector import mapper
 from veho.vector.length import length
 
-from pyspare.margin import EntriesMargin
-from pyspare.padder.pad_entries import pad_entries
+from pyspare.margin import EntriesMargin, entries_margin
+from pyspare.padder.entries_padder import entries_padder
 
 
 def deco_entries(
@@ -26,13 +26,37 @@ def deco_entries(
         inner_bracket: int = PAR,
         ansi: bool = False,
         dash: str = COSP
+):
+    size = length(entries)
+    if not size: return str(entries)
+    entries = entries_margin(entries, head, tail, key_read, read, ELLIP)
+    if delim.find(LF) >= 0: entries = entries_padder(entries, ansi)
+    if presets: entries = fluo_entries(entries, presets, effects, colorant=False, mutate=True)
+    br = to_br(inner_bracket) or oneself
+    lines = mapper(entries, lambda kv: br(kv[0] + dash + kv[1].rstrip()))
+    return liner(lines, delim=delim, bracket=bracket)
+
+
+def deco_entries_arch(
+        entries: list,
+        key_read: Callable = None,
+        read: Callable = None,
+        head: int = None,
+        tail: int = None,
+        presets: Tuple[Preset] = (FRESH, PLANET),
+        effects: List[str] = None,
+        delim: str = COLF,
+        bracket: int = BRK,
+        inner_bracket: int = PAR,
+        ansi: bool = False,
+        dash: str = COSP
 ):
     size = length(entries)
     if not size: return str(entries)
     vn = EntriesMargin.build(entries, head, tail)
     raw, text = vn.to_list(ELLIP), vn.stringify(key_read, read).to_list(ELLIP)
     dye = fluo_entries(raw, presets, effects, colorant=True, mutate=True) if presets else None
-    entries = pad_entries(text, raw, dye, ansi=presets or ansi) \
+    entries = entries_padder(text, raw, dye, ansi=presets or ansi) \
         if delim.find(LF) >= 0 \
         else zipper(text, dye, lambda tx, dy: dy(tx)) if presets else text
     brk = to_br(inner_bracket) or oneself
